Struct amazon_sp_vendor_direct_fulfillment_shipping::models::shipment_confirmation::ShipmentConfirmation
source · [−]pub struct ShipmentConfirmation {
pub purchase_order_number: String,
pub shipment_details: Box<ShipmentDetails>,
pub selling_party: Box<PartyIdentification>,
pub ship_from_party: Box<PartyIdentification>,
pub items: Vec<Item>,
pub containers: Option<Vec<Container>>,
}Fields
purchase_order_number: StringPurchase order number corresponding to the shipment.
shipment_details: Box<ShipmentDetails>selling_party: Box<PartyIdentification>ship_from_party: Box<PartyIdentification>items: Vec<Item>Provide the details of the items in this shipment. If any of the item details field is common at a package or a pallet level, then provide them at the corresponding package.
containers: Option<Vec<Container>>Provide the details of the items in this shipment. If any of the item details field is common at a package or a pallet level, then provide them at the corresponding package.
Implementations
sourceimpl ShipmentConfirmation
impl ShipmentConfirmation
pub fn new(
purchase_order_number: String,
shipment_details: ShipmentDetails,
selling_party: PartyIdentification,
ship_from_party: PartyIdentification,
items: Vec<Item>
) -> ShipmentConfirmation